import {Component, OnInit} from '@angular/core';
import {AdminIndexService} from "../../../services/admin-index.service";
import {FormBuilder} from "@angular/forms";
import {Router} from "@angular/router";
import {NzMessageService, NzModalService} from "ng-zorro-antd";
import {HttpClient} from "../../../../../node_modules/@angular/common/http";

@Component({
  selector: 'app-index',
  templateUrl: './index.component.html',
  styleUrls: ['./index.component.less']
})
export class IndexComponent implements OnInit {
  positionTopTen = {};
  resumeByAge = {};
  resumeByEdu = {};
  enterpriseTopTen = {};
  deliveryByMonth = {};

  constructor(
    private fb: FormBuilder,
    private router: Router,  // 路由
    private message: NzMessageService,
    private http: HttpClient,
    private modalService: NzModalService,
    private adminIndexService: AdminIndexService,
  ) { }

  ngOnInit(): void {
    this.getPositionTopTen();
    this.findResumeByAge();
    this.findResumeByEdu();
    this.getEnterpriseTopTen();
    this.findDeliveryByMonth();
  }

  // 按职位类型统计前十职位数量
  getPositionTopTen() {
    this.adminIndexService.getPositionTopTen(data => {
      if (data['return_code'] === '000000') {
        this.positionTopTen = {
          title: {
            text: '职位发布数量排名',
          },
          color: ['#3398DB'],
          tooltip: {
            trigger: 'axis',
            axisPointer: {            // 坐标轴指示器，坐标轴触发有效
              type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
            }
          },
          grid: {
            left: '3%',
            right: '4%',
            bottom: '3%',
            containLabel: true
          },
          xAxis: [
            {
              type: 'category',
              data: data['return_data']['label'],
              axisTick: {
                alignWithLabel: true
              }
            }
          ],
          yAxis: [
            {
              type: 'value'
            }
          ],
          series: [
            {
              name: '',
              type: 'bar',
              barWidth: '60%',
              data: data['return_data']['value']
            }
          ]
        };
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }
  // 按年龄段统计简历
  findResumeByAge() {
    this.adminIndexService.findResumeByAge(data => {
      if (data['return_code'] === '000000') {
        this.resumeByAge = {
          title: {
            text: '人才库年龄分布',
          },
          tooltip: {
            trigger: 'item',
            formatter: '{a}{b} : {c} ({d}%)'
          },
          legend: {
            orient: 'vertical',
            bottom: 'bottom',
            // right: 'right',
            width: '20%',
            itemWidth: 15,
            itemHeight: 15,
            textStyle: {
              color: '#000000'
            },
            data: data['return_data']['label']
          },
          series: [
            {
              name: '',
              type: 'pie',
              radius: ['40%', '60%'],
              hoverAnimation: true,
              clockwise: false,
              data: data['return_data']['data'],
              itemStyle: {
                hoverAnimation: false,
                normal: {
                  borderWidth: 6,
                  // borderColor: '#011358',
                  color: function (params) {
                    var colorList = ['#e69a2a', '#ff9745', '#3a51ec', '#e7b82e', '#34abff','#2F4554'];
                    return colorList[params.dataIndex];
                  }
                }
              }
            }
          ]
        };
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 按学历统计简历
  findResumeByEdu() {
    this.adminIndexService.findResumeByEdu(data => {
      if (data['return_code'] === '000000') {
        this.resumeByEdu = {
          title: {
            text: '人才库学历分布',
          },
          tooltip: {
            trigger: 'item',
            formatter: '{a}{b}: {c} ({d}%)'
          },
          legend: {
            orient: 'vertical',
            bottom: 'bottom',
            itemWidth: 10,
            itemHeight: 10,
            textStyle: {
              color: '#000000'
            },
            data: ['博士', '硕士', '本科', '大专', '大专以下', '学历不限']
          },
          series: [
            {
              name: '',
              type: 'pie',
              label: {
                show: false,
                position: 'center'
              },
              data: data['return_data']['value'],
              itemStyle: {
                normal: {
                  color: function (params) {
                    var colorList = ['#749F83', '#91C7AE', '#D48265', '#61A0A8', '#2F4554', '#C23531'];
                    return colorList[params.dataIndex];
                  }
                }
              }
            }
          ]
        };
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 按行业统计前十企业数量
  getEnterpriseTopTen() {
    this.adminIndexService.getEnterpriseTopTen(data => {
      if (data['return_code'] === '000000') {
        this.enterpriseTopTen = {
          title: {
            text: '行业分类企业数量排名',
          },
          color: ['#3398DB'],
          tooltip: {
            trigger: 'axis',
            axisPointer: {            // 坐标轴指示器，坐标轴触发有效
              type: 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
            }
          },
          grid: {
            left: '3%',
            right: '4%',
            bottom: '3%',
            containLabel: true
          },
          xAxis: [
            {
              type: 'category',
              data: data['return_data']['label'],
              axisTick: {
                alignWithLabel: true
              }
            }
          ],
          yAxis: [
            {
              type: 'value'
            }
          ],
          series: [
            {
              name: '',
              type: 'bar',
              barWidth: '60%',
              data: data['return_data']['value']
            }
          ]
        };
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }

  // 当前年份按月统计简历投递数
  findDeliveryByMonth() {
    this.adminIndexService.findDeliveryByMonth(data => {
      if (data['return_code'] === '000000') {
        this.deliveryByMonth = {
          title: {
            text: '今年每月简历投递数(总计：' + data['return_data']['total'] +")",
          },
          tooltip: {
            position: ['50%', '50%']
          },
          xAxis: {
            type: 'category',
            data: data['return_data']['label']
          },
          yAxis: {
            type: 'value',
            axisTick: {
              show: false
            }
          },
          lineStyle: {
            color: '#132363'
          },
          itemStyle: {
            color: '#43b0f6'
          },
          series: [{
            data: data['return_data']['data'],
            type: 'line'
          }]
        };
      } else {
        this.message.error(data['return_msg']);
      }
    });
  }
}
